import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Rating(_message.Message):
    __slots__ = ("id", "timestamp", "member_id", "contest_id", "value", "level")
    ID_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    LEVEL_FIELD_NUMBER: _ClassVar[int]
    id: str
    timestamp: _timestamp_pb2.Timestamp
    member_id: str
    contest_id: str
    value: int
    level: int
    def __init__(self, id: _Optional[str] = ..., timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., member_id: _Optional[str] = ..., contest_id: _Optional[str] = ..., value: _Optional[int] = ..., level: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class EnumServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def CreateEnum(self, request, **kwargs):
        path = "/enums"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.taxonomy.CreateEnumOutput"),
            **kwargs,
        )

    def DeleteEnum(self, request, **kwargs):
        path = "/enums/"+urllib.parse.quote(request.enum_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.enum_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.taxonomy.DeleteEnumOutput"),
            **kwargs,
        )

    def UpdateEnum(self, request, **kwargs):
        path = "/enums/"+urllib.parse.quote(request.enum_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.enum_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.taxonomy.UpdateEnumOutput"),
            **kwargs,
        )

    def DescribeEnum(self, request, **kwargs):
        path = "/enums/"+urllib.parse.quote(request.enum_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.enum_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.taxonomy.DescribeEnumOutput"),
            **kwargs,
        )

    def ListEnums(self, request, **kwargs):
        path = "/enums"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.taxonomy.ListEnumsOutput"),
            **kwargs,
        )

    def CreateValue(self, request, **kwargs):
        path = "/enums/"+urllib.parse.quote(request.enum_id)+"/items"

        # Cleanup URL parameters to avoid any ambiguity
        request.enum_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.taxonomy.CreateValueOutput"),
            **kwargs,
        )

    def DeleteValue(self, request, **kwargs):
        path = "/enums/"+urllib.parse.quote(request.enum_id)+"/values/"+urllib.parse.quote(request.value_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.enum_id = ""
        request.value_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.taxonomy.DeleteValueOutput"),
            **kwargs,
        )

    def UpdateValue(self, request, **kwargs):
        path = "/enums/"+urllib.parse.quote(request.enum_id)+"/values/"+urllib.parse.quote(request.value_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.enum_id = ""
        request.value_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.taxonomy.UpdateValueOutput"),
            **kwargs,
        )

    def DescribeValue(self, request, **kwargs):
        path = "/enums/"+urllib.parse.quote(request.enum_id)+"/values/"+urllib.parse.quote(request.value_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.enum_id = ""
        request.value_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.taxonomy.DescribeValueOutput"),
            **kwargs,
        )

    def ListValues(self, request, **kwargs):
        path = "/enums/"+urllib.parse.quote(request.enum_id)+"/items"

        # Cleanup URL parameters to avoid any ambiguity
        request.enum_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.taxonomy.ListValuesOutput"),
            **kwargs,
        )

    def TranslateValue(self, request, **kwargs):
        path = "/enums/"+urllib.parse.quote(request.enum_id)+"/values/"+urllib.parse.quote(request.value_id)+"/translations/"+urllib.parse.quote(request.locale)

        # Cleanup URL parameters to avoid any ambiguity
        request.enum_id = ""
        request.value_id = ""
        request.locale = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.taxonomy.TranslateValueOutput"),
            **kwargs,
        )

    def DeleteTranslation(self, request, **kwargs):
        path = "/enums/"+urllib.parse.quote(request.enum_id)+"/values/"+urllib.parse.quote(request.value_id)+"/translations/"+urllib.parse.quote(request.locale)

        # Cleanup URL parameters to avoid any ambiguity
        request.enum_id = ""
        request.value_id = ""
        request.locale = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.taxonomy.DeleteTranslationOutput"),
            **kwargs,
        )

    def ListTranslations(self, request, **kwargs):
        path = "/enums/"+urllib.parse.quote(request.enum_id)+"/values/"+urllib.parse.quote(request.value_id)+"/translations"

        # Cleanup URL parameters to avoid any ambiguity
        request.enum_id = ""
        request.value_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.taxonomy.ListTranslationsOutput"),
            **kwargs,
        )




import datetime

from eolymp.judge import medal_pb2 as _medal_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Participant(_message.Message):
    __slots__ = ("id", "member_id", "display_name", "role", "unofficial", "inactive", "disqualified", "ghost", "finalized", "medal", "status", "started_at", "end_at", "bonus_time", "violation_count", "passcode", "certificate_id", "submits")
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_STATUS: _ClassVar[Participant.Status]
        WAITING: _ClassVar[Participant.Status]
        READY: _ClassVar[Participant.Status]
        ACTIVE: _ClassVar[Participant.Status]
        COMPLETE: _ClassVar[Participant.Status]
        UPSOLVE: _ClassVar[Participant.Status]
        BLOCKED: _ClassVar[Participant.Status]
        PAUSED: _ClassVar[Participant.Status]
    UNKNOWN_STATUS: Participant.Status
    WAITING: Participant.Status
    READY: Participant.Status
    ACTIVE: Participant.Status
    COMPLETE: Participant.Status
    UPSOLVE: Participant.Status
    BLOCKED: Participant.Status
    PAUSED: Participant.Status
    class Role(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        PARTICIPANT: _ClassVar[Participant.Role]
        STAFF: _ClassVar[Participant.Role]
        TESTER: _ClassVar[Participant.Role]
        AUTHOR: _ClassVar[Participant.Role]
        COORDINATOR: _ClassVar[Participant.Role]
    PARTICIPANT: Participant.Role
    STAFF: Participant.Role
    TESTER: Participant.Role
    AUTHOR: Participant.Role
    COORDINATOR: Participant.Role
    class Patch(_message.Message):
        __slots__ = ()
        class Field(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            ALL: _ClassVar[Participant.Patch.Field]
            DISPLAY_NAME: _ClassVar[Participant.Patch.Field]
            ROLE: _ClassVar[Participant.Patch.Field]
            BONUS_TIME: _ClassVar[Participant.Patch.Field]
            UNOFFICIAL: _ClassVar[Participant.Patch.Field]
            MEDAL: _ClassVar[Participant.Patch.Field]
            INACTIVE: _ClassVar[Participant.Patch.Field]
            PASSCODE: _ClassVar[Participant.Patch.Field]
        ALL: Participant.Patch.Field
        DISPLAY_NAME: Participant.Patch.Field
        ROLE: Participant.Patch.Field
        BONUS_TIME: Participant.Patch.Field
        UNOFFICIAL: Participant.Patch.Field
        MEDAL: Participant.Patch.Field
        INACTIVE: Participant.Patch.Field
        PASSCODE: Participant.Patch.Field
        def __init__(self) -> None: ...
    class Submit(_message.Message):
        __slots__ = ("problem_id", "counter")
        PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
        COUNTER_FIELD_NUMBER: _ClassVar[int]
        problem_id: str
        counter: int
        def __init__(self, problem_id: _Optional[str] = ..., counter: _Optional[int] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    UNOFFICIAL_FIELD_NUMBER: _ClassVar[int]
    INACTIVE_FIELD_NUMBER: _ClassVar[int]
    DISQUALIFIED_FIELD_NUMBER: _ClassVar[int]
    GHOST_FIELD_NUMBER: _ClassVar[int]
    FINALIZED_FIELD_NUMBER: _ClassVar[int]
    MEDAL_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    STARTED_AT_FIELD_NUMBER: _ClassVar[int]
    END_AT_FIELD_NUMBER: _ClassVar[int]
    BONUS_TIME_FIELD_NUMBER: _ClassVar[int]
    VIOLATION_COUNT_FIELD_NUMBER: _ClassVar[int]
    PASSCODE_FIELD_NUMBER: _ClassVar[int]
    CERTIFICATE_ID_FIELD_NUMBER: _ClassVar[int]
    SUBMITS_FIELD_NUMBER: _ClassVar[int]
    id: str
    member_id: str
    display_name: str
    role: Participant.Role
    unofficial: bool
    inactive: bool
    disqualified: bool
    ghost: bool
    finalized: bool
    medal: _medal_pb2.Medal
    status: Participant.Status
    started_at: _timestamp_pb2.Timestamp
    end_at: _timestamp_pb2.Timestamp
    bonus_time: int
    violation_count: int
    passcode: str
    certificate_id: str
    submits: _containers.RepeatedCompositeFieldContainer[Participant.Submit]
    def __init__(self, id: _Optional[str] = ..., member_id: _Optional[str] = ..., display_name: _Optional[str] = ..., role: _Optional[_Union[Participant.Role, str]] = ..., unofficial: bool = ..., inactive: bool = ..., disqualified: bool = ..., ghost: bool = ..., finalized: bool = ..., medal: _Optional[_Union[_medal_pb2.Medal, str]] = ..., status: _Optional[_Union[Participant.Status, str]] = ..., started_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., end_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., bonus_time: _Optional[int] = ..., violation_count: _Optional[int] = ..., passcode: _Optional[str] = ..., certificate_id: _Optional[str] = ..., submits: _Optional[_Iterable[_Union[Participant.Submit, _Mapping]]] = ...) -> None: ...



from .sso_service_pb2 import *
from .linked_account_service_http import *
from .linked_account_service_pb2 import *
from .oauth2_service_pb2 import *
from .oauth2_service_http import *
from .linked_account_pb2 import *
from .security_event_pb2 import *
from .sso_service_http import *
from .claims_pb2 import *



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/ranker/ranker.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/ranker/ranker.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.ranker import activity_pb2 as eolymp_dot_ranker_dot_activity__pb2
from eolymp.ranker import scoreboard_pb2 as eolymp_dot_ranker_dot_scoreboard__pb2
from eolymp.ranker import scoreboard_service_pb2 as eolymp_dot_ranker_dot_scoreboard__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/ranker/ranker.proto\x12\reolymp.ranker\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1c\x65olymp/ranker/activity.proto\x1a\x1e\x65olymp/ranker/scoreboard.proto\x1a&eolymp/ranker/scoreboard_service.proto\"J\n\x13ListActivitiesInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"M\n\x14ListActivitiesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.ranker.Activity\"^\n\x13ScheduleActionInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x30\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32 .eolymp.ranker.Scoreboard.Action\")\n\x14ScheduleActionOutput\x12\x11\n\taction_id\x18\x01 \x01(\t\"A\n\x15UnscheduleActionInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x11\n\taction_id\x18\x02 \x01(\t\"\x18\n\x16UnscheduleActionOutput\"2\n\x19ListScheduledActionsInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\\\n\x1aListScheduledActionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12/\n\x05items\x18\x02 \x03(\x0b\x32 .eolymp.ranker.Scoreboard.Action2\xfe\x19\n\x06Ranker\x12\xa3\x01\n\x10\x43reateScoreboard\x12$.eolymp.ranker.CreateScoreboardInput\x1a%.eolymp.ranker.CreateScoreboardOutput\"B\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\x0e\"\x0c/scoreboards\x12\xb3\x01\n\x10UpdateScoreboard\x12$.eolymp.ranker.UpdateScoreboardInput\x1a%.eolymp.ranker.UpdateScoreboardOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\x1e\x1a\x1c/scoreboards/{scoreboard_id}\x12\xbe\x01\n\x11RebuildScoreboard\x12%.eolymp.ranker.RebuildScoreboardInput\x1a&.eolymp.ranker.RebuildScoreboardOutput\"Z\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02&\"$/scoreboards/{scoreboard_id}/rebuild\x12\xb3\x01\n\x10\x44\x65leteScoreboard\x12$.eolymp.ranker.DeleteScoreboardInput\x1a%.eolymp.ranker.DeleteScoreboardOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\x1e*\x1c/scoreboards/{scoreboard_id}\x12\xb8\x01\n\x12\x44\x65scribeScoreboard\x12&.eolymp.ranker.DescribeScoreboardInput\x1a\'.eolymp.ranker.DescribeScoreboardOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02\x1e\x12\x1c/scoreboards/{scoreboard_id}\x12\x9f\x01\n\x0fListScoreboards\x12#.eolymp.ranker.ListScoreboardsInput\x1a$.eolymp.ranker.ListScoreboardsOutput\"A\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02\x0e\x12\x0c/scoreboards\x12\xd2\x01\n\x15\x44\x65scribeScoreboardRow\x12).eolymp.ranker.DescribeScoreboardRowInput\x1a*.eolymp.ranker.DescribeScoreboardRowOutput\"b\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02/\x12-/scoreboards/{scoreboard_id}/rows/{member_id}\x12\xbd\x01\n\x12ListScoreboardRows\x12&.eolymp.ranker.ListScoreboardRowsInput\x1a\'.eolymp.ranker.ListScoreboardRowsOutput\"V\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02#\x12!/scoreboards/{scoreboard_id}/rows\x12\xc4\x01\n\x13\x41\x64\x64ScoreboardColumn\x12\'.eolymp.ranker.AddScoreboardColumnInput\x1a(.eolymp.ranker.AddScoreboardColumnOutput\"Z\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02&\"$/scoreboards/{scoreboard_id}/columns\x12\xd9\x01\n\x16UpdateScoreboardColumn\x12*.eolymp.ranker.UpdateScoreboardColumnInput\x1a+.eolymp.ranker.UpdateScoreboardColumnOutput\"f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\x32\x1a\x30/scoreboards/{scoreboard_id}/columns/{column_id}\x12\xd9\x01\n\x16\x44\x65leteScoreboardColumn\x12*.eolymp.ranker.DeleteScoreboardColumnInput\x1a+.eolymp.ranker.DeleteScoreboardColumnOutput\"f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\x32*0/scoreboards/{scoreboard_id}/columns/{column_id}\x12\xde\x01\n\x18\x44\x65scribeScoreboardColumn\x12,.eolymp.ranker.DescribeScoreboardColumnInput\x1a-.eolymp.ranker.DescribeScoreboardColumnOutput\"e\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02\x32\x12\x30/scoreboards/{scoreboard_id}/columns/{column_id}\x12\xc9\x01\n\x15ListScoreboardColumns\x12).eolymp.ranker.ListScoreboardColumnsInput\x1a*.eolymp.ranker.ListScoreboardColumnsOutput\"Y\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02&\x12$/scoreboards/{scoreboard_id}/columns\x12\xb3\x01\n\x0eListActivities\x12\".eolymp.ranker.ListActivitiesInput\x1a#.eolymp.ranker.ListActivitiesOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02)\x12\'/scoreboards/{scoreboard_id}/activities\x12\xb6\x01\n\x0eScheduleAction\x12\".eolymp.ranker.ScheduleActionInput\x1a#.eolymp.ranker.ScheduleActionOutput\"[\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\'\"%/scoreboards/{scoreboard_id}/schedule\x12\xc8\x01\n\x10UnscheduleAction\x12$.eolymp.ranker.UnscheduleActionInput\x1a%.eolymp.ranker.UnscheduleActionOutput\"g\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\x33*1/scoreboards/{scoreboard_id}/schedule/{action_id}\x12\xc8\x01\n\x14ListScheduledActions\x12(.eolymp.ranker.ListScheduledActionsInput\x1a).eolymp.ranker.ListScheduledActionsOutput\"[\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\n\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\'\x12%/scoreboards/{scoreboard_id}/scheduleB/Z-github.com/eolymp/go-sdk/eolymp/ranker;rankerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.ranker.ranker_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/ranker;ranker'
  _globals['_RANKER'].methods_by_name['CreateScoreboard']._loaded_options = None
  _globals['_RANKER'].methods_by_name['CreateScoreboard']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\002\016\"\014/scoreboards'
  _globals['_RANKER'].methods_by_name['UpdateScoreboard']._loaded_options = None
  _globals['_RANKER'].methods_by_name['UpdateScoreboard']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\002\036\032\034/scoreboards/{scoreboard_id}'
  _globals['_RANKER'].methods_by_name['RebuildScoreboard']._loaded_options = None
  _globals['_RANKER'].methods_by_name['RebuildScoreboard']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\002&\"$/scoreboards/{scoreboard_id}/rebuild'
  _globals['_RANKER'].methods_by_name['DeleteScoreboard']._loaded_options = None
  _globals['_RANKER'].methods_by_name['DeleteScoreboard']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\002\036*\034/scoreboards/{scoreboard_id}'
  _globals['_RANKER'].methods_by_name['DescribeScoreboard']._loaded_options = None
  _globals['_RANKER'].methods_by_name['DescribeScoreboard']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\002\036\022\034/scoreboards/{scoreboard_id}'
  _globals['_RANKER'].methods_by_name['ListScoreboards']._loaded_options = None
  _globals['_RANKER'].methods_by_name['ListScoreboards']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\002\016\022\014/scoreboards'
  _globals['_RANKER'].methods_by_name['DescribeScoreboardRow']._loaded_options = None
  _globals['_RANKER'].methods_by_name['DescribeScoreboardRow']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\002/\022-/scoreboards/{scoreboard_id}/rows/{member_id}'
  _globals['_RANKER'].methods_by_name['ListScoreboardRows']._loaded_options = None
  _globals['_RANKER'].methods_by_name['ListScoreboardRows']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\002#\022!/scoreboards/{scoreboard_id}/rows'
  _globals['_RANKER'].methods_by_name['AddScoreboardColumn']._loaded_options = None
  _globals['_RANKER'].methods_by_name['AddScoreboardColumn']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\002&\"$/scoreboards/{scoreboard_id}/columns'
  _globals['_RANKER'].methods_by_name['UpdateScoreboardColumn']._loaded_options = None
  _globals['_RANKER'].methods_by_name['UpdateScoreboardColumn']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\0022\0320/scoreboards/{scoreboard_id}/columns/{column_id}'
  _globals['_RANKER'].methods_by_name['DeleteScoreboardColumn']._loaded_options = None
  _globals['_RANKER'].methods_by_name['DeleteScoreboardColumn']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\0022*0/scoreboards/{scoreboard_id}/columns/{column_id}'
  _globals['_RANKER'].methods_by_name['DescribeScoreboardColumn']._loaded_options = None
  _globals['_RANKER'].methods_by_name['DescribeScoreboardColumn']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\0022\0220/scoreboards/{scoreboard_id}/columns/{column_id}'
  _globals['_RANKER'].methods_by_name['ListScoreboardColumns']._loaded_options = None
  _globals['_RANKER'].methods_by_name['ListScoreboardColumns']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\002&\022$/scoreboards/{scoreboard_id}/columns'
  _globals['_RANKER'].methods_by_name['ListActivities']._loaded_options = None
  _globals['_RANKER'].methods_by_name['ListActivities']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002)\022\'/scoreboards/{scoreboard_id}/activities'
  _globals['_RANKER'].methods_by_name['ScheduleAction']._loaded_options = None
  _globals['_RANKER'].methods_by_name['ScheduleAction']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\002\'\"%/scoreboards/{scoreboard_id}/schedule'
  _globals['_RANKER'].methods_by_name['UnscheduleAction']._loaded_options = None
  _globals['_RANKER'].methods_by_name['UnscheduleAction']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\0023*1/scoreboards/{scoreboard_id}/schedule/{action_id}'
  _globals['_RANKER'].methods_by_name['ListScheduledActions']._loaded_options = None
  _globals['_RANKER'].methods_by_name['ListScheduledActions']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\n\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\002\'\022%/scoreboards/{scoreboard_id}/schedule'
  _globals['_LISTACTIVITIESINPUT']._serialized_start=246
  _globals['_LISTACTIVITIESINPUT']._serialized_end=320
  _globals['_LISTACTIVITIESOUTPUT']._serialized_start=322
  _globals['_LISTACTIVITIESOUTPUT']._serialized_end=399
  _globals['_SCHEDULEACTIONINPUT']._serialized_start=401
  _globals['_SCHEDULEACTIONINPUT']._serialized_end=495
  _globals['_SCHEDULEACTIONOUTPUT']._serialized_start=497
  _globals['_SCHEDULEACTIONOUTPUT']._serialized_end=538
  _globals['_UNSCHEDULEACTIONINPUT']._serialized_start=540
  _globals['_UNSCHEDULEACTIONINPUT']._serialized_end=605
  _globals['_UNSCHEDULEACTIONOUTPUT']._serialized_start=607
  _globals['_UNSCHEDULEACTIONOUTPUT']._serialized_end=631
  _globals['_LISTSCHEDULEDACTIONSINPUT']._serialized_start=633
  _globals['_LISTSCHEDULEDACTIONSINPUT']._serialized_end=683
  _globals['_LISTSCHEDULEDACTIONSOUTPUT']._serialized_start=685
  _globals['_LISTSCHEDULEDACTIONSOUTPUT']._serialized_end=777
  _globals['_RANKER']._serialized_start=780
  _globals['_RANKER']._serialized_end=4106
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.auth import linked_account_pb2 as _linked_account_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SignonRequestInput(_message.Message):
    __slots__ = ("type", "callback_uri")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CALLBACK_URI_FIELD_NUMBER: _ClassVar[int]
    type: _linked_account_pb2.LinkedAccount.Type
    callback_uri: str
    def __init__(self, type: _Optional[_Union[_linked_account_pb2.LinkedAccount.Type, str]] = ..., callback_uri: _Optional[str] = ...) -> None: ...

class SignonRequestOutput(_message.Message):
    __slots__ = ("redirect_uri",)
    REDIRECT_URI_FIELD_NUMBER: _ClassVar[int]
    redirect_uri: str
    def __init__(self, redirect_uri: _Optional[str] = ...) -> None: ...

class SignonExchangeInput(_message.Message):
    __slots__ = ("code", "state")
    CODE_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    code: str
    state: str
    def __init__(self, code: _Optional[str] = ..., state: _Optional[str] = ...) -> None: ...

class SignonExchangeOutput(_message.Message):
    __slots__ = ("access_token", "token_type", "expires_in", "refresh_token")
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOKEN_TYPE_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_IN_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    token_type: str
    expires_in: int
    refresh_token: str
    def __init__(self, access_token: _Optional[str] = ..., token_type: _Optional[str] = ..., expires_in: _Optional[int] = ..., refresh_token: _Optional[str] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.judge import violation_pb2 as _violation_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateViolationInput(_message.Message):
    __slots__ = ("violation", "dont_notify")
    VIOLATION_FIELD_NUMBER: _ClassVar[int]
    DONT_NOTIFY_FIELD_NUMBER: _ClassVar[int]
    violation: _violation_pb2.Violation
    dont_notify: bool
    def __init__(self, violation: _Optional[_Union[_violation_pb2.Violation, _Mapping]] = ..., dont_notify: bool = ...) -> None: ...

class CreateViolationOutput(_message.Message):
    __slots__ = ("violation_id",)
    VIOLATION_ID_FIELD_NUMBER: _ClassVar[int]
    violation_id: str
    def __init__(self, violation_id: _Optional[str] = ...) -> None: ...

class UpdateViolationInput(_message.Message):
    __slots__ = ("patch", "violation_id", "violation")
    PATCH_FIELD_NUMBER: _ClassVar[int]
    VIOLATION_ID_FIELD_NUMBER: _ClassVar[int]
    VIOLATION_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[_violation_pb2.Violation.Patch.Field]
    violation_id: str
    violation: _violation_pb2.Violation
    def __init__(self, patch: _Optional[_Iterable[_Union[_violation_pb2.Violation.Patch.Field, str]]] = ..., violation_id: _Optional[str] = ..., violation: _Optional[_Union[_violation_pb2.Violation, _Mapping]] = ...) -> None: ...

class UpdateViolationOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteViolationInput(_message.Message):
    __slots__ = ("violation_id",)
    VIOLATION_ID_FIELD_NUMBER: _ClassVar[int]
    violation_id: str
    def __init__(self, violation_id: _Optional[str] = ...) -> None: ...

class DeleteViolationOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeViolationInput(_message.Message):
    __slots__ = ("violation_id",)
    VIOLATION_ID_FIELD_NUMBER: _ClassVar[int]
    violation_id: str
    def __init__(self, violation_id: _Optional[str] = ...) -> None: ...

class DescribeViolationOutput(_message.Message):
    __slots__ = ("violation",)
    VIOLATION_FIELD_NUMBER: _ClassVar[int]
    violation: _violation_pb2.Violation
    def __init__(self, violation: _Optional[_Union[_violation_pb2.Violation, _Mapping]] = ...) -> None: ...

class ListViolationsInput(_message.Message):
    __slots__ = ("offset", "size", "filters")
    class Filter(_message.Message):
        __slots__ = ("id", "status", "type", "summary", "automatic", "participant_id", "submission_id", "created_by", "confirmed_by")
        ID_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        SUMMARY_FIELD_NUMBER: _ClassVar[int]
        AUTOMATIC_FIELD_NUMBER: _ClassVar[int]
        PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
        SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
        CREATED_BY_FIELD_NUMBER: _ClassVar[int]
        CONFIRMED_BY_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        status: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        type: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        summary: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        automatic: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        participant_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        submission_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        created_by: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        confirmed_by: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., status: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., type: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., summary: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., automatic: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., participant_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., submission_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., created_by: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., confirmed_by: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ...) -> None: ...
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    filters: ListViolationsInput.Filter
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListViolationsInput.Filter, _Mapping]] = ...) -> None: ...

class ListViolationsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_violation_pb2.Violation]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_violation_pb2.Violation, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/l10n/translation_pair.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/l10n/translation_pair.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.l10n import term_pb2 as eolymp_dot_l10n_dot_term__pb2
from eolymp.l10n import translation_pb2 as eolymp_dot_l10n_dot_translation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/l10n/translation_pair.proto\x12\x0b\x65olymp.l10n\x1a\x16\x65olymp/l10n/term.proto\x1a\x1d\x65olymp/l10n/translation.proto\"\xb9\x01\n\x0fTranslationPair\x12\x1f\n\x04term\x18\x01 \x01(\x0b\x32\x11.eolymp.l10n.Term\x12(\n\x06source\x18\x02 \x01(\x0b\x32\x18.eolymp.l10n.Translation\x12-\n\x0btranslation\x18\x03 \x01(\x0b\x32\x18.eolymp.l10n.Translation\x12,\n\nsuggestion\x18\x04 \x01(\x0b\x32\x18.eolymp.l10n.TranslationB+Z)github.com/eolymp/go-sdk/eolymp/l10n;l10nb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.l10n.translation_pair_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/eolymp/go-sdk/eolymp/l10n;l10n'
  _globals['_TRANSLATIONPAIR']._serialized_start=107
  _globals['_TRANSLATIONPAIR']._serialized_end=292
# @@protoc_insertion_point(module_scope)



from eolymp.commerce import address_pb2 as _address_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ShoppingCart(_message.Message):
    __slots__ = ("id", "items", "billing_address", "shipping_address", "billing_same_as_shipping", "currency", "total_amount", "shipping_amount", "discount_amount", "tax_amount", "tax_rate", "tax_note", "grand_total")
    class Item(_message.Message):
        __slots__ = ("id", "product_id", "variant_id", "quantity", "unit_amount", "total_amount", "discount_amount")
        ID_FIELD_NUMBER: _ClassVar[int]
        PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
        VARIANT_ID_FIELD_NUMBER: _ClassVar[int]
        QUANTITY_FIELD_NUMBER: _ClassVar[int]
        UNIT_AMOUNT_FIELD_NUMBER: _ClassVar[int]
        TOTAL_AMOUNT_FIELD_NUMBER: _ClassVar[int]
        DISCOUNT_AMOUNT_FIELD_NUMBER: _ClassVar[int]
        id: str
        product_id: str
        variant_id: str
        quantity: int
        unit_amount: int
        total_amount: int
        discount_amount: int
        def __init__(self, id: _Optional[str] = ..., product_id: _Optional[str] = ..., variant_id: _Optional[str] = ..., quantity: _Optional[int] = ..., unit_amount: _Optional[int] = ..., total_amount: _Optional[int] = ..., discount_amount: _Optional[int] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    BILLING_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    SHIPPING_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    BILLING_SAME_AS_SHIPPING_FIELD_NUMBER: _ClassVar[int]
    CURRENCY_FIELD_NUMBER: _ClassVar[int]
    TOTAL_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    SHIPPING_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    DISCOUNT_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    TAX_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    TAX_RATE_FIELD_NUMBER: _ClassVar[int]
    TAX_NOTE_FIELD_NUMBER: _ClassVar[int]
    GRAND_TOTAL_FIELD_NUMBER: _ClassVar[int]
    id: str
    items: _containers.RepeatedCompositeFieldContainer[ShoppingCart.Item]
    billing_address: _address_pb2.Address
    shipping_address: _address_pb2.Address
    billing_same_as_shipping: bool
    currency: str
    total_amount: int
    shipping_amount: int
    discount_amount: int
    tax_amount: int
    tax_rate: int
    tax_note: str
    grand_total: int
    def __init__(self, id: _Optional[str] = ..., items: _Optional[_Iterable[_Union[ShoppingCart.Item, _Mapping]]] = ..., billing_address: _Optional[_Union[_address_pb2.Address, _Mapping]] = ..., shipping_address: _Optional[_Union[_address_pb2.Address, _Mapping]] = ..., billing_same_as_shipping: bool = ..., currency: _Optional[str] = ..., total_amount: _Optional[int] = ..., shipping_amount: _Optional[int] = ..., discount_amount: _Optional[int] = ..., tax_amount: _Optional[int] = ..., tax_rate: _Optional[int] = ..., tax_note: _Optional[str] = ..., grand_total: _Optional[int] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Test(_message.Message):
    __slots__ = ("id", "version_id", "testset_id", "index", "status", "status_message", "example", "inactive", "secret", "score", "example_input_url", "example_answer_url", "generated_input_url", "generated_answer_url", "input_url", "input_generator", "answer_url", "answer_generator")
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_STATUS: _ClassVar[Test.Status]
        PENDING: _ClassVar[Test.Status]
        READY: _ClassVar[Test.Status]
        INVALID: _ClassVar[Test.Status]
    UNKNOWN_STATUS: Test.Status
    PENDING: Test.Status
    READY: Test.Status
    INVALID: Test.Status
    class Generator(_message.Message):
        __slots__ = ("script_name", "arguments")
        SCRIPT_NAME_FIELD_NUMBER: _ClassVar[int]
        ARGUMENTS_FIELD_NUMBER: _ClassVar[int]
        script_name: str
        arguments: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, script_name: _Optional[str] = ..., arguments: _Optional[_Iterable[str]] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_ID_FIELD_NUMBER: _ClassVar[int]
    TESTSET_ID_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    STATUS_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    EXAMPLE_FIELD_NUMBER: _ClassVar[int]
    INACTIVE_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    EXAMPLE_INPUT_URL_FIELD_NUMBER: _ClassVar[int]
    EXAMPLE_ANSWER_URL_FIELD_NUMBER: _ClassVar[int]
    GENERATED_INPUT_URL_FIELD_NUMBER: _ClassVar[int]
    GENERATED_ANSWER_URL_FIELD_NUMBER: _ClassVar[int]
    INPUT_URL_FIELD_NUMBER: _ClassVar[int]
    INPUT_GENERATOR_FIELD_NUMBER: _ClassVar[int]
    ANSWER_URL_FIELD_NUMBER: _ClassVar[int]
    ANSWER_GENERATOR_FIELD_NUMBER: _ClassVar[int]
    id: str
    version_id: str
    testset_id: str
    index: int
    status: Test.Status
    status_message: str
    example: bool
    inactive: bool
    secret: bool
    score: float
    example_input_url: str
    example_answer_url: str
    generated_input_url: str
    generated_answer_url: str
    input_url: str
    input_generator: Test.Generator
    answer_url: str
    answer_generator: Test.Generator
    def __init__(self, id: _Optional[str] = ..., version_id: _Optional[str] = ..., testset_id: _Optional[str] = ..., index: _Optional[int] = ..., status: _Optional[_Union[Test.Status, str]] = ..., status_message: _Optional[str] = ..., example: bool = ..., inactive: bool = ..., secret: bool = ..., score: _Optional[float] = ..., example_input_url: _Optional[str] = ..., example_answer_url: _Optional[str] = ..., generated_input_url: _Optional[str] = ..., generated_answer_url: _Optional[str] = ..., input_url: _Optional[str] = ..., input_generator: _Optional[_Union[Test.Generator, _Mapping]] = ..., answer_url: _Optional[str] = ..., answer_generator: _Optional[_Union[Test.Generator, _Mapping]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.runtime import runtime_pb2 as _runtime_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Editor(_message.Message):
    __slots__ = ("state", "features", "runtimes")
    class Feature(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_FEATURE: _ClassVar[Editor.Feature]
        PRINT_CODE: _ClassVar[Editor.Feature]
        RUN_CODE: _ClassVar[Editor.Feature]
        UPLOAD_CODE: _ClassVar[Editor.Feature]
        EDIT_CODE: _ClassVar[Editor.Feature]
    UNKNOWN_FEATURE: Editor.Feature
    PRINT_CODE: Editor.Feature
    RUN_CODE: Editor.Feature
    UPLOAD_CODE: Editor.Feature
    EDIT_CODE: Editor.Feature
    class State(_message.Message):
        __slots__ = ("runtime", "source_code", "input_data")
        RUNTIME_FIELD_NUMBER: _ClassVar[int]
        SOURCE_CODE_FIELD_NUMBER: _ClassVar[int]
        INPUT_DATA_FIELD_NUMBER: _ClassVar[int]
        runtime: str
        source_code: str
        input_data: str
        def __init__(self, runtime: _Optional[str] = ..., source_code: _Optional[str] = ..., input_data: _Optional[str] = ...) -> None: ...
    STATE_FIELD_NUMBER: _ClassVar[int]
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    RUNTIMES_FIELD_NUMBER: _ClassVar[int]
    state: Editor.State
    features: _containers.RepeatedScalarFieldContainer[Editor.Feature]
    runtimes: _containers.RepeatedCompositeFieldContainer[_runtime_pb2.Runtime]
    def __init__(self, state: _Optional[_Union[Editor.State, _Mapping]] = ..., features: _Optional[_Iterable[_Union[Editor.Feature, str]]] = ..., runtimes: _Optional[_Iterable[_Union[_runtime_pb2.Runtime, _Mapping]]] = ...) -> None: ...

class DescribeEditorInput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeEditorOutput(_message.Message):
    __slots__ = ("editor",)
    EDITOR_FIELD_NUMBER: _ClassVar[int]
    editor: Editor
    def __init__(self, editor: _Optional[_Union[Editor, _Mapping]] = ...) -> None: ...

class DescribeEditorStateInput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeEditorStateOutput(_message.Message):
    __slots__ = ("runtime", "source_code", "input_data", "features")
    RUNTIME_FIELD_NUMBER: _ClassVar[int]
    SOURCE_CODE_FIELD_NUMBER: _ClassVar[int]
    INPUT_DATA_FIELD_NUMBER: _ClassVar[int]
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    runtime: str
    source_code: str
    input_data: str
    features: _containers.RepeatedScalarFieldContainer[Editor.Feature]
    def __init__(self, runtime: _Optional[str] = ..., source_code: _Optional[str] = ..., input_data: _Optional[str] = ..., features: _Optional[_Iterable[_Union[Editor.Feature, str]]] = ...) -> None: ...

class UpdateEditorStateInput(_message.Message):
    __slots__ = ("runtime", "source_code", "input_data")
    RUNTIME_FIELD_NUMBER: _ClassVar[int]
    SOURCE_CODE_FIELD_NUMBER: _ClassVar[int]
    INPUT_DATA_FIELD_NUMBER: _ClassVar[int]
    runtime: str
    source_code: str
    input_data: str
    def __init__(self, runtime: _Optional[str] = ..., source_code: _Optional[str] = ..., input_data: _Optional[str] = ...) -> None: ...

class UpdateEditorStateOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class PrintEditorCodeInput(_message.Message):
    __slots__ = ("runtime", "source_code")
    RUNTIME_FIELD_NUMBER: _ClassVar[int]
    SOURCE_CODE_FIELD_NUMBER: _ClassVar[int]
    runtime: str
    source_code: str
    def __init__(self, runtime: _Optional[str] = ..., source_code: _Optional[str] = ...) -> None: ...

class PrintEditorCodeOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UploadImageInput(_message.Message):
    __slots__ = ("name", "type", "crop", "size", "variants", "data")
    class Size(_message.Message):
        __slots__ = ("width", "height")
        WIDTH_FIELD_NUMBER: _ClassVar[int]
        HEIGHT_FIELD_NUMBER: _ClassVar[int]
        width: int
        height: int
        def __init__(self, width: _Optional[int] = ..., height: _Optional[int] = ...) -> None: ...
    class Crop(_message.Message):
        __slots__ = ("top", "right", "bottom", "left")
        TOP_FIELD_NUMBER: _ClassVar[int]
        RIGHT_FIELD_NUMBER: _ClassVar[int]
        BOTTOM_FIELD_NUMBER: _ClassVar[int]
        LEFT_FIELD_NUMBER: _ClassVar[int]
        top: int
        right: int
        bottom: int
        left: int
        def __init__(self, top: _Optional[int] = ..., right: _Optional[int] = ..., bottom: _Optional[int] = ..., left: _Optional[int] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CROP_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    VARIANTS_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    name: str
    type: str
    crop: UploadImageInput.Crop
    size: UploadImageInput.Size
    variants: _containers.RepeatedCompositeFieldContainer[UploadImageInput.Size]
    data: bytes
    def __init__(self, name: _Optional[str] = ..., type: _Optional[str] = ..., crop: _Optional[_Union[UploadImageInput.Crop, _Mapping]] = ..., size: _Optional[_Union[UploadImageInput.Size, _Mapping]] = ..., variants: _Optional[_Iterable[_Union[UploadImageInput.Size, _Mapping]]] = ..., data: _Optional[bytes] = ...) -> None: ...

class UploadImageOutput(_message.Message):
    __slots__ = ("image_url",)
    IMAGE_URL_FIELD_NUMBER: _ClassVar[int]
    image_url: str
    def __init__(self, image_url: _Optional[str] = ...) -> None: ...

class UploadFileInput(_message.Message):
    __slots__ = ("name", "type", "data")
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    name: str
    type: str
    data: bytes
    def __init__(self, name: _Optional[str] = ..., type: _Optional[str] = ..., data: _Optional[bytes] = ...) -> None: ...

class UploadFileOutput(_message.Message):
    __slots__ = ("file_url",)
    FILE_URL_FIELD_NUMBER: _ClassVar[int]
    file_url: str
    def __init__(self, file_url: _Optional[str] = ...) -> None: ...

class UploadAssetInput(_message.Message):
    __slots__ = ("name", "type", "keys", "ttl", "data")
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    KEYS_FIELD_NUMBER: _ClassVar[int]
    TTL_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    name: str
    type: str
    keys: _containers.RepeatedScalarFieldContainer[str]
    ttl: int
    data: bytes
    def __init__(self, name: _Optional[str] = ..., type: _Optional[str] = ..., keys: _Optional[_Iterable[str]] = ..., ttl: _Optional[int] = ..., data: _Optional[bytes] = ...) -> None: ...

class UploadAssetOutput(_message.Message):
    __slots__ = ("asset_url",)
    ASSET_URL_FIELD_NUMBER: _ClassVar[int]
    asset_url: str
    def __init__(self, asset_url: _Optional[str] = ...) -> None: ...

class LookupAssetInput(_message.Message):
    __slots__ = ("key",)
    KEY_FIELD_NUMBER: _ClassVar[int]
    key: str
    def __init__(self, key: _Optional[str] = ...) -> None: ...

class LookupAssetOutput(_message.Message):
    __slots__ = ("asset_url",)
    ASSET_URL_FIELD_NUMBER: _ClassVar[int]
    asset_url: str
    def __init__(self, asset_url: _Optional[str] = ...) -> None: ...

class StartMultipartUploadInput(_message.Message):
    __slots__ = ("name", "type", "keys", "ttl")
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    KEYS_FIELD_NUMBER: _ClassVar[int]
    TTL_FIELD_NUMBER: _ClassVar[int]
    name: str
    type: str
    keys: _containers.RepeatedScalarFieldContainer[str]
    ttl: int
    def __init__(self, name: _Optional[str] = ..., type: _Optional[str] = ..., keys: _Optional[_Iterable[str]] = ..., ttl: _Optional[int] = ...) -> None: ...

class StartMultipartUploadOutput(_message.Message):
    __slots__ = ("upload_id",)
    UPLOAD_ID_FIELD_NUMBER: _ClassVar[int]
    upload_id: str
    def __init__(self, upload_id: _Optional[str] = ...) -> None: ...

class UploadPartInput(_message.Message):
    __slots__ = ("upload_id", "part_number", "data")
    UPLOAD_ID_FIELD_NUMBER: _ClassVar[int]
    PART_NUMBER_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    upload_id: str
    part_number: int
    data: bytes
    def __init__(self, upload_id: _Optional[str] = ..., part_number: _Optional[int] = ..., data: _Optional[bytes] = ...) -> None: ...

class UploadPartOutput(_message.Message):
    __slots__ = ("token",)
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    token: str
    def __init__(self, token: _Optional[str] = ...) -> None: ...

class CompleteMultipartUploadInput(_message.Message):
    __slots__ = ("upload_id", "parts")
    class Part(_message.Message):
        __slots__ = ("number", "token", "checksum_md5", "checksum_sha1", "checksum_sha256")
        NUMBER_FIELD_NUMBER: _ClassVar[int]
        TOKEN_FIELD_NUMBER: _ClassVar[int]
        CHECKSUM_MD5_FIELD_NUMBER: _ClassVar[int]
        CHECKSUM_SHA1_FIELD_NUMBER: _ClassVar[int]
        CHECKSUM_SHA256_FIELD_NUMBER: _ClassVar[int]
        number: int
        token: str
        checksum_md5: str
        checksum_sha1: str
        checksum_sha256: str
        def __init__(self, number: _Optional[int] = ..., token: _Optional[str] = ..., checksum_md5: _Optional[str] = ..., checksum_sha1: _Optional[str] = ..., checksum_sha256: _Optional[str] = ...) -> None: ...
    UPLOAD_ID_FIELD_NUMBER: _ClassVar[int]
    PARTS_FIELD_NUMBER: _ClassVar[int]
    upload_id: str
    parts: _containers.RepeatedCompositeFieldContainer[CompleteMultipartUploadInput.Part]
    def __init__(self, upload_id: _Optional[str] = ..., parts: _Optional[_Iterable[_Union[CompleteMultipartUploadInput.Part, _Mapping]]] = ...) -> None: ...

class CompleteMultipartUploadOutput(_message.Message):
    __slots__ = ("asset_url",)
    ASSET_URL_FIELD_NUMBER: _ClassVar[int]
    asset_url: str
    def __init__(self, asset_url: _Optional[str] = ...) -> None: ...

class StartStreamInput(_message.Message):
    __slots__ = ("name", "type", "ttl")
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    TTL_FIELD_NUMBER: _ClassVar[int]
    name: str
    type: str
    ttl: int
    def __init__(self, name: _Optional[str] = ..., type: _Optional[str] = ..., ttl: _Optional[int] = ...) -> None: ...

class StartStreamOutput(_message.Message):
    __slots__ = ("stream_id", "stream_url")
    STREAM_ID_FIELD_NUMBER: _ClassVar[int]
    STREAM_URL_FIELD_NUMBER: _ClassVar[int]
    stream_id: str
    stream_url: str
    def __init__(self, stream_id: _Optional[str] = ..., stream_url: _Optional[str] = ...) -> None: ...

class AppendStreamInput(_message.Message):
    __slots__ = ("stream_id", "offset", "data")
    STREAM_ID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    stream_id: str
    offset: int
    data: bytes
    def __init__(self, stream_id: _Optional[str] = ..., offset: _Optional[int] = ..., data: _Optional[bytes] = ...) -> None: ...

class AppendStreamOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class CloseStreamInput(_message.Message):
    __slots__ = ("stream_id",)
    STREAM_ID_FIELD_NUMBER: _ClassVar[int]
    stream_id: str
    def __init__(self, stream_id: _Optional[str] = ...) -> None: ...

class CloseStreamOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class FeedbackPolicy(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    COMPLETE: _ClassVar[FeedbackPolicy]
    ICPC: _ClassVar[FeedbackPolicy]
    ICPC_EXPANDED: _ClassVar[FeedbackPolicy]
COMPLETE: FeedbackPolicy
ICPC: FeedbackPolicy
ICPC_EXPANDED: FeedbackPolicy



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/course/problem_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/course/problem_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import code_template_pb2 as eolymp_dot_atlas_dot_code__template__pb2
from eolymp.atlas import statement_pb2 as eolymp_dot_atlas_dot_statement__pb2
from eolymp.atlas import testing_test_pb2 as eolymp_dot_atlas_dot_testing__test__pb2
from eolymp.course import submission_service_pb2 as eolymp_dot_course_dot_submission__service__pb2
from eolymp.playground import run_pb2 as eolymp_dot_playground_dot_run__pb2
from eolymp.runtime import runtime_pb2 as eolymp_dot_runtime_dot_runtime__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/course/problem_service.proto\x12\reolymp.course\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a eolymp/atlas/code_template.proto\x1a\x1c\x65olymp/atlas/statement.proto\x1a\x1f\x65olymp/atlas/testing_test.proto\x1a&eolymp/course/submission_service.proto\x1a\x1b\x65olymp/playground/run.proto\x1a\x1c\x65olymp/runtime/runtime.proto\"\x15\n\x13ListStatementsInput\"M\n\x14ListStatementsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.atlas.Statement\"&\n\x14LookupStatementInput\x12\x0e\n\x06locale\x18\x02 \x01(\t\"C\n\x15LookupStatementOutput\x12*\n\tstatement\x18\x02 \x01(\x0b\x32\x17.eolymp.atlas.Statement\"\x13\n\x11ListExamplesInput\":\n\x12ListExamplesOutput\x12$\n\x08\x65xamples\x18\x02 \x03(\x0b\x32\x12.eolymp.atlas.Test\"*\n\x17LookupCodeTemplateInput\x12\x0f\n\x07runtime\x18\x01 \x01(\t\"D\n\x18LookupCodeTemplateOutput\x12(\n\x08template\x18\x01 \x01(\x0b\x32\x16.eolymp.atlas.Template\"e\n\x0e\x43reateRunInput\x12\x0f\n\x07runtime\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x64 \x01(\t\x12\x14\n\ninput_data\x18\x65 \x01(\x0cH\x00\x12\x13\n\tinput_ref\x18\x66 \x01(\tH\x00\x42\x07\n\x05input\"!\n\x0f\x43reateRunOutput\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"\"\n\x10\x44\x65scribeRunInput\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"8\n\x11\x44\x65scribeRunOutput\x12#\n\x03run\x18\x01 \x01(\x0b\x32\x16.eolymp.playground.Run\"\x1f\n\rWatchRunInput\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"5\n\x0eWatchRunOutput\x12#\n\x03run\x18\x01 \x01(\x0b\x32\x16.eolymp.playground.Run\"\x13\n\x11ListRuntimesInput\"K\n\x12ListRuntimesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.runtime.Runtime2\xb9\x0e\n\x0eProblemService\x12\x97\x01\n\x0eListStatements\x12\".eolymp.course.ListStatementsInput\x1a#.eolymp.course.ListStatementsOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02\r\x12\x0b/statements\x12\xa1\x01\n\x0fLookupStatement\x12#.eolymp.course.LookupStatementInput\x1a$.eolymp.course.LookupStatementOutput\"C\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\x14\x12\x12/statements:lookup\x12\x8f\x01\n\x0cListExamples\x12 .eolymp.course.ListExamplesInput\x1a!.eolymp.course.ListExamplesOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02\x0b\x12\t/examples\x12\xa0\x01\n\x10\x43reateSubmission\x12$.eolymp.course.CreateSubmissionInput\x1a%.eolymp.course.CreateSubmissionOutput\"?\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\n\x82\xe3\n\x18\x8a\xe3\n\x14\x63ourse:course:submit\x82\xd3\xe4\x93\x02\x0e\"\x0c/submissions\x12\x9b\x01\n\x0fListSubmissions\x12#.eolymp.course.ListSubmissionsInput\x1a$.eolymp.course.ListSubmissionsOutput\"=\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02\x0e\x12\x0c/submissions\x12\xb4\x01\n\x12\x44\x65scribeSubmission\x12&.eolymp.course.DescribeSubmissionInput\x1a\'.eolymp.course.DescribeSubmissionOutput\"M\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02\x1e\x12\x1c/submissions/{submission_id}\x12z\n\x0fWatchSubmission\x12#.eolymp.course.WatchSubmissionInput\x1a$.eolymp.course.WatchSubmissionOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read0\x01\x12\xa1\x01\n\x12LookupCodeTemplate\x12&.eolymp.course.LookupCodeTemplateInput\x1a\'.eolymp.course.LookupCodeTemplateOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02\x0b\x12\t/template\x12\x84\x01\n\tCreateRun\x12\x1d.eolymp.course.CreateRunInput\x1a\x1e.eolymp.course.CreateRunOutput\"8\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x18\x8a\xe3\n\x14playground:run:write\x82\xd3\xe4\x93\x02\x07\"\x05/runs\x12\x92\x01\n\x0b\x44\x65scribeRun\x12\x1f.eolymp.course.DescribeRunInput\x1a .eolymp.course.DescribeRunOutput\"@\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x17\x8a\xe3\n\x13playground:run:read\x82\xd3\xe4\x93\x02\x10\x12\x0e/runs/{run_id}\x12\x91\x01\n\x08WatchRun\x12\x1c.eolymp.course.WatchRunInput\x1a\x1d.eolymp.course.WatchRunOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x17\x8a\xe3\n\x13playground:run:read\x82\xd3\xe4\x93\x02\x16\x12\x14/runs/{run_id}/watch0\x01\x12\x8e\x01\n\x0cListRuntimes\x12 .eolymp.course.ListRuntimesInput\x1a!.eolymp.course.ListRuntimesOutput\"9\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x19\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02\n\x12\x08/runtimeB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.problem_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _globals['_PROBLEMSERVICE'].methods_by_name['ListStatements']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['ListStatements']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002\r\022\013/statements'
  _globals['_PROBLEMSERVICE'].methods_by_name['LookupStatement']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['LookupStatement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\024\022\022/statements:lookup'
  _globals['_PROBLEMSERVICE'].methods_by_name['ListExamples']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['ListExamples']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002\013\022\t/examples'
  _globals['_PROBLEMSERVICE'].methods_by_name['CreateSubmission']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['CreateSubmission']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\n\202\343\n\030\212\343\n\024course:course:submit\202\323\344\223\002\016\"\014/submissions'
  _globals['_PROBLEMSERVICE'].methods_by_name['ListSubmissions']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['ListSubmissions']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002\016\022\014/submissions'
  _globals['_PROBLEMSERVICE'].methods_by_name['DescribeSubmission']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['DescribeSubmission']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002\036\022\034/submissions/{submission_id}'
  _globals['_PROBLEMSERVICE'].methods_by_name['WatchSubmission']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['WatchSubmission']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read'
  _globals['_PROBLEMSERVICE'].methods_by_name['LookupCodeTemplate']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['LookupCodeTemplate']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002\013\022\t/template'
  _globals['_PROBLEMSERVICE'].methods_by_name['CreateRun']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['CreateRun']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\030\212\343\n\024playground:run:write\202\323\344\223\002\007\"\005/runs'
  _globals['_PROBLEMSERVICE'].methods_by_name['DescribeRun']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['DescribeRun']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\027\212\343\n\023playground:run:read\202\323\344\223\002\020\022\016/runs/{run_id}'
  _globals['_PROBLEMSERVICE'].methods_by_name['WatchRun']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['WatchRun']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\027\212\343\n\023playground:run:read\202\323\344\223\002\026\022\024/runs/{run_id}/watch'
  _globals['_PROBLEMSERVICE'].methods_by_name['ListRuntimes']._loaded_options = None
  _globals['_PROBLEMSERVICE'].methods_by_name['ListRuntimes']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\031\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002\n\022\010/runtime'
  _globals['_LISTSTATEMENTSINPUT']._serialized_start=349
  _globals['_LISTSTATEMENTSINPUT']._serialized_end=370
  _globals['_LISTSTATEMENTSOUTPUT']._serialized_start=372
  _globals['_LISTSTATEMENTSOUTPUT']._serialized_end=449
  _globals['_LOOKUPSTATEMENTINPUT']._serialized_start=451
  _globals['_LOOKUPSTATEMENTINPUT']._serialized_end=489
  _globals['_LOOKUPSTATEMENTOUTPUT']._serialized_start=491
  _globals['_LOOKUPSTATEMENTOUTPUT']._serialized_end=558
  _globals['_LISTEXAMPLESINPUT']._serialized_start=560
  _globals['_LISTEXAMPLESINPUT']._serialized_end=579
  _globals['_LISTEXAMPLESOUTPUT']._serialized_start=581
  _globals['_LISTEXAMPLESOUTPUT']._serialized_end=639
  _globals['_LOOKUPCODETEMPLATEINPUT']._serialized_start=641
  _globals['_LOOKUPCODETEMPLATEINPUT']._serialized_end=683
  _globals['_LOOKUPCODETEMPLATEOUTPUT']._serialized_start=685
  _globals['_LOOKUPCODETEMPLATEOUTPUT']._serialized_end=753
  _globals['_CREATERUNINPUT']._serialized_start=755
  _globals['_CREATERUNINPUT']._serialized_end=856
  _globals['_CREATERUNOUTPUT']._serialized_start=858
  _globals['_CREATERUNOUTPUT']._serialized_end=891
  _globals['_DESCRIBERUNINPUT']._serialized_start=893
  _globals['_DESCRIBERUNINPUT']._serialized_end=927
  _globals['_DESCRIBERUNOUTPUT']._serialized_start=929
  _globals['_DESCRIBERUNOUTPUT']._serialized_end=985
  _globals['_WATCHRUNINPUT']._serialized_start=987
  _globals['_WATCHRUNINPUT']._serialized_end=1018
  _globals['_WATCHRUNOUTPUT']._serialized_start=1020
  _globals['_WATCHRUNOUTPUT']._serialized_end=1073
  _globals['_LISTRUNTIMESINPUT']._serialized_start=1075
  _globals['_LISTRUNTIMESINPUT']._serialized_end=1094
  _globals['_LISTRUNTIMESOUTPUT']._serialized_start=1096
  _globals['_LISTRUNTIMESOUTPUT']._serialized_end=1171
  _globals['_PROBLEMSERVICE']._serialized_start=1174
  _globals['_PROBLEMSERVICE']._serialized_end=3023
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/commerce/order_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/commerce/order_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.commerce import order_pb2 as eolymp_dot_commerce_dot_order__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/commerce/order_service.proto\x12\x0f\x65olymp.commerce\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1b\x65olymp/commerce/order.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"$\n\x10\x43\x61ncelOrderInput\x12\x10\n\x08order_id\x18\x01 \x01(\t\"\x13\n\x11\x43\x61ncelOrderOutput\"&\n\x12\x44\x65scribeOrderInput\x12\x10\n\x08order_id\x18\x01 \x01(\t\"<\n\x13\x44\x65scribeOrderOutput\x12%\n\x05order\x18\x01 \x01(\x0b\x32\x16.eolymp.commerce.Order\"\xad\x02\n\x0fListOrdersInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06search\x18\x14 \x01(\t\x12\x38\n\x07\x66ilters\x18( \x01(\x0b\x32\'.eolymp.commerce.ListOrdersInput.Filter\x12\x37\n\x04sort\x18\x32 \x01(\x0e\x32).eolymp.commerce.ListOrdersInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x1a\x34\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"\x17\n\x08Sortable\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\"H\n\x10ListOrdersOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.commerce.Order2\x80\x04\n\x0cOrderService\x12\xab\x01\n\x0b\x43\x61ncelOrder\x12!.eolymp.commerce.CancelOrderInput\x1a\".eolymp.commerce.CancelOrderOutput\"U\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1b\x8a\xe3\n\x17\x63ommerce:shopping:write\x82\xd3\xe4\x93\x02!\"\x1f/store/orders/{order_id}/cancel\x12\xa9\x01\n\rDescribeOrder\x12#.eolymp.commerce.DescribeOrderInput\x1a$.eolymp.commerce.DescribeOrderOutput\"M\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommerce:shopping:read\x82\xd3\xe4\x93\x02\x1a\"\x18/store/orders/{order_id}\x12\x95\x01\n\nListOrders\x12 .eolymp.commerce.ListOrdersInput\x1a!.eolymp.commerce.ListOrdersOutput\"B\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommerce:shopping:read\x82\xd3\xe4\x93\x02\x0f\x12\r/store/ordersB3Z1github.com/eolymp/go-sdk/eolymp/commerce;commerceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.commerce.order_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/commerce;commerce'
  _globals['_ORDERSERVICE'].methods_by_name['CancelOrder']._loaded_options = None
  _globals['_ORDERSERVICE'].methods_by_name['CancelOrder']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\033\212\343\n\027commerce:shopping:write\202\323\344\223\002!\"\037/store/orders/{order_id}/cancel'
  _globals['_ORDERSERVICE'].methods_by_name['DescribeOrder']._loaded_options = None
  _globals['_ORDERSERVICE'].methods_by_name['DescribeOrder']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\032\212\343\n\026commerce:shopping:read\202\323\344\223\002\032\"\030/store/orders/{order_id}'
  _globals['_ORDERSERVICE'].methods_by_name['ListOrders']._loaded_options = None
  _globals['_ORDERSERVICE'].methods_by_name['ListOrders']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\032\212\343\n\026commerce:shopping:read\202\323\344\223\002\017\022\r/store/orders'
  _globals['_CANCELORDERINPUT']._serialized_start=253
  _globals['_CANCELORDERINPUT']._serialized_end=289
  _globals['_CANCELORDEROUTPUT']._serialized_start=291
  _globals['_CANCELORDEROUTPUT']._serialized_end=310
  _globals['_DESCRIBEORDERINPUT']._serialized_start=312
  _globals['_DESCRIBEORDERINPUT']._serialized_end=350
  _globals['_DESCRIBEORDEROUTPUT']._serialized_start=352
  _globals['_DESCRIBEORDEROUTPUT']._serialized_end=412
  _globals['_LISTORDERSINPUT']._serialized_start=415
  _globals['_LISTORDERSINPUT']._serialized_end=716
  _globals['_LISTORDERSINPUT_FILTER']._serialized_start=639
  _globals['_LISTORDERSINPUT_FILTER']._serialized_end=691
  _globals['_LISTORDERSINPUT_SORTABLE']._serialized_start=693
  _globals['_LISTORDERSINPUT_SORTABLE']._serialized_end=716
  _globals['_LISTORDERSOUTPUT']._serialized_start=718
  _globals['_LISTORDERSOUTPUT']._serialized_end=790
  _globals['_ORDERSERVICE']._serialized_start=793
  _globals['_ORDERSERVICE']._serialized_end=1305
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/commerce/price.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/commerce/price.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/commerce/price.proto\x12\x0f\x65olymp.commerce\"\xbd\x01\n\x05Price\x12\n\n\x02id\x18\x01 \x01(\t\x12\x35\n\nrecurrence\x18\x03 \x01(\x0e\x32!.eolymp.commerce.Price.Recurrence\x12\x10\n\x08\x63urrency\x18\x1e \x01(\t\x12\x13\n\x0bunit_amount\x18\x1f \x01(\x05\"J\n\nRecurrence\x12\x16\n\x12UNKNOWN_RECURRENCE\x10\x00\x12\x0b\n\x07ONETIME\x10\x01\x12\x0b\n\x07MONTHLY\x10\x02\x12\n\n\x06YEARLY\x10\x03\x42\x33Z1github.com/eolymp/go-sdk/eolymp/commerce;commerceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.commerce.price_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/commerce;commerce'
  _globals['_PRICE']._serialized_start=49
  _globals['_PRICE']._serialized_end=238
  _globals['_PRICE_RECURRENCE']._serialized_start=164
  _globals['_PRICE_RECURRENCE']._serialized_end=238
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.community import attribute_pb2 as _attribute_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateAttributeInput(_message.Message):
    __slots__ = ("attribute_key", "attribute")
    ATTRIBUTE_KEY_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_FIELD_NUMBER: _ClassVar[int]
    attribute_key: str
    attribute: _attribute_pb2.Attribute
    def __init__(self, attribute_key: _Optional[str] = ..., attribute: _Optional[_Union[_attribute_pb2.Attribute, _Mapping]] = ...) -> None: ...

class CreateAttributeOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UpdateAttributeInput(_message.Message):
    __slots__ = ("patch", "attribute_key", "attribute")
    PATCH_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_KEY_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[_attribute_pb2.Attribute.Patch]
    attribute_key: str
    attribute: _attribute_pb2.Attribute
    def __init__(self, patch: _Optional[_Iterable[_Union[_attribute_pb2.Attribute.Patch, str]]] = ..., attribute_key: _Optional[str] = ..., attribute: _Optional[_Union[_attribute_pb2.Attribute, _Mapping]] = ...) -> None: ...

class UpdateAttributeOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RemoveAttributeInput(_message.Message):
    __slots__ = ("attribute_key",)
    ATTRIBUTE_KEY_FIELD_NUMBER: _ClassVar[int]
    attribute_key: str
    def __init__(self, attribute_key: _Optional[str] = ...) -> None: ...

class RemoveAttributeOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeAttributeInput(_message.Message):
    __slots__ = ("attribute_key",)
    ATTRIBUTE_KEY_FIELD_NUMBER: _ClassVar[int]
    attribute_key: str
    def __init__(self, attribute_key: _Optional[str] = ...) -> None: ...

class DescribeAttributeOutput(_message.Message):
    __slots__ = ("attribute",)
    ATTRIBUTE_FIELD_NUMBER: _ClassVar[int]
    attribute: _attribute_pb2.Attribute
    def __init__(self, attribute: _Optional[_Union[_attribute_pb2.Attribute, _Mapping]] = ...) -> None: ...

class ListAttributesInput(_message.Message):
    __slots__ = ("offset", "size", "filters")
    class Filter(_message.Message):
        __slots__ = ("id", "key", "hidden", "required", "type")
        ID_FIELD_NUMBER: _ClassVar[int]
        KEY_FIELD_NUMBER: _ClassVar[int]
        HIDDEN_FIELD_NUMBER: _ClassVar[int]
        REQUIRED_FIELD_NUMBER: _ClassVar[int]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        key: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        hidden: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        required: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        type: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., key: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., hidden: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., required: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., type: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    filters: ListAttributesInput.Filter
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListAttributesInput.Filter, _Mapping]] = ...) -> None: ...

class ListAttributesOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_attribute_pb2.Attribute]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_attribute_pb2.Attribute, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/bookmark_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/atlas/bookmark_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/atlas/bookmark_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\"\\\n\x14\x42ookmarkChangedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\x12\x0e\n\x06\x62\x65\x66ore\x18\x03 \x01(\x08\x12\r\n\x05\x61\x66ter\x18\x04 \x01(\x08\"$\n\x10SetBookmarkInput\x12\x10\n\x08\x62ookmark\x18\x02 \x01(\x08\"\x13\n\x11SetBookmarkOutput\"\x12\n\x10GetBookmarkInput\"%\n\x11GetBookmarkOutput\x12\x10\n\x08\x62ookmark\x18\x01 \x01(\x08\x32\xf5\x01\n\x0f\x42ookmarkService\x12p\n\x0bGetBookmark\x12\x1e.eolymp.atlas.GetBookmarkInput\x1a\x1f.eolymp.atlas.GetBookmarkOutput\" \xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xc8\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0b\x12\t/bookmark\x12p\n\x0bSetBookmark\x12\x1e.eolymp.atlas.SetBookmarkInput\x1a\x1f.eolymp.atlas.SetBookmarkOutput\" \xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x0b\"\t/bookmarkB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.bookmark_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_BOOKMARKSERVICE'].methods_by_name['GetBookmark']._loaded_options = None
  _globals['_BOOKMARKSERVICE'].methods_by_name['GetBookmark']._serialized_options = b'\352\342\n\013\365\342\n\000\000\310A\370\342\nd\202\323\344\223\002\013\022\t/bookmark'
  _globals['_BOOKMARKSERVICE'].methods_by_name['SetBookmark']._loaded_options = None
  _globals['_BOOKMARKSERVICE'].methods_by_name['SetBookmark']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\013\"\t/bookmark'
  _globals['_BOOKMARKCHANGEDEVENT']._serialized_start=120
  _globals['_BOOKMARKCHANGEDEVENT']._serialized_end=212
  _globals['_SETBOOKMARKINPUT']._serialized_start=214
  _globals['_SETBOOKMARKINPUT']._serialized_end=250
  _globals['_SETBOOKMARKOUTPUT']._serialized_start=252
  _globals['_SETBOOKMARKOUTPUT']._serialized_end=271
  _globals['_GETBOOKMARKINPUT']._serialized_start=273
  _globals['_GETBOOKMARKINPUT']._serialized_end=291
  _globals['_GETBOOKMARKOUTPUT']._serialized_start=293
  _globals['_GETBOOKMARKOUTPUT']._serialized_end=330
  _globals['_BOOKMARKSERVICE']._serialized_start=333
  _globals['_BOOKMARKSERVICE']._serialized_end=578
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/community/configuration_identity.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/community/configuration_identity.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.community import configuration_idp_pb2 as eolymp_dot_community_dot_configuration__idp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-eolymp/community/configuration_identity.proto\x12\x10\x65olymp.community\x1a(eolymp/community/configuration_idp.proto\"\xc9\x03\n\x0eIdentityConfig\x12\x39\n\x05local\x18\x01 \x01(\x0b\x32(.eolymp.community.IdentityProvider.LocalH\x00\x12?\n\x08\x62\x61secamp\x18\x02 \x01(\x0b\x32+.eolymp.community.IdentityProvider.BasecampH\x00\x12\x37\n\x04oidc\x18\x03 \x01(\x0b\x32\'.eolymp.community.IdentityProvider.OIDCH\x00\x12K\n\x11\x64isplay_name_type\x18\x64 \x01(\x0e\x32\x30.eolymp.community.IdentityConfig.DisplayNameType\x12\x1e\n\x16\x64isplay_name_attribute\x18\x65 \x01(\t\x12\x15\n\rallow_sign_up\x18\x66 \x01(\x08\x12\x1e\n\x16require_email_verified\x18g \x01(\x08\"R\n\x0f\x44isplayNameType\x12\x18\n\x14UNKNOWN_DISPLAY_NAME\x10\x00\x12\x0c\n\x08NICKNAME\x10\x01\x12\x08\n\x04NAME\x10\x02\x12\r\n\tATTRIBUTE\x10\x03\x42\n\n\x08providerB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.configuration_identity_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _globals['_IDENTITYCONFIG']._serialized_start=110
  _globals['_IDENTITYCONFIG']._serialized_end=567
  _globals['_IDENTITYCONFIG_DISPLAYNAMETYPE']._serialized_start=473
  _globals['_IDENTITYCONFIG_DISPLAYNAMETYPE']._serialized_end=555
# @@protoc_insertion_point(module_scope)



import datetime

from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Suggestion(_message.Message):
    __slots__ = ("id", "status", "locale", "title", "member_id", "created_at", "updated_at", "topics", "difficulty", "statement", "editorial")
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_STATUS: _ClassVar[Suggestion.Status]
        PENDING: _ClassVar[Suggestion.Status]
        IN_REVIEW: _ClassVar[Suggestion.Status]
        APPROVED: _ClassVar[Suggestion.Status]
        REJECTED: _ClassVar[Suggestion.Status]
    UNKNOWN_STATUS: Suggestion.Status
    PENDING: Suggestion.Status
    IN_REVIEW: Suggestion.Status
    APPROVED: Suggestion.Status
    REJECTED: Suggestion.Status
    ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    TOPICS_FIELD_NUMBER: _ClassVar[int]
    DIFFICULTY_FIELD_NUMBER: _ClassVar[int]
    STATEMENT_FIELD_NUMBER: _ClassVar[int]
    EDITORIAL_FIELD_NUMBER: _ClassVar[int]
    id: str
    status: Suggestion.Status
    locale: str
    title: str
    member_id: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    topics: _containers.RepeatedScalarFieldContainer[str]
    difficulty: int
    statement: _content_pb2.Content
    editorial: _content_pb2.Content
    def __init__(self, id: _Optional[str] = ..., status: _Optional[_Union[Suggestion.Status, str]] = ..., locale: _Optional[str] = ..., title: _Optional[str] = ..., member_id: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., topics: _Optional[_Iterable[str]] = ..., difficulty: _Optional[int] = ..., statement: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., editorial: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/version.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/atlas/version.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/atlas/version.proto\x12\x0c\x65olymp.atlas\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc3\x02\n\x07Version\x12\n\n\x02id\x18\x06 \x01(\t\x12\x0e\n\x06number\x18\x01 \x01(\r\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x03 \x01(\t\x12\x0f\n\x07summary\x18\t \x01(\t\x12-\n\x07\x63hanges\x18\n \x03(\x0b\x32\x1c.eolymp.atlas.Version.Change\x12\x0e\n\x06\x63ursor\x18\x64 \x01(\t\x1a\x43\n\x06\x43hange\x12+\n\x02op\x18\x01 \x01(\x0e\x32\x1f.eolymp.atlas.Version.Operation\x12\x0c\n\x04path\x18\x02 \x01(\t\"C\n\tOperation\x12\x15\n\x11UNKNOWN_OPERATION\x10\x00\x12\x07\n\x03\x41\x44\x44\x10\x01\x12\n\n\x06UPDATE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\x42-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.version_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_VERSION']._serialized_start=78
  _globals['_VERSION']._serialized_end=401
  _globals['_VERSION_CHANGE']._serialized_start=265
  _globals['_VERSION_CHANGE']._serialized_end=332
  _globals['_VERSION_OPERATION']._serialized_start=334
  _globals['_VERSION_OPERATION']._serialized_end=401
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/scoring_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/atlas/scoring_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import scoring_score_pb2 as eolymp_dot_atlas_dot_scoring__score__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/atlas/scoring_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a eolymp/atlas/scoring_score.proto\"\x83\x01\n\x11ScoreChangedEvent\x12\x12\n\nproblem_id\x18\x03 \x01(\t\x12\x11\n\tmember_id\x18\x04 \x01(\t\x12#\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x13.eolymp.atlas.Score\x12\"\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x13.eolymp.atlas.Score\"\'\n\x12\x44\x65scribeScoreInput\x12\x11\n\tmember_id\x18\x02 \x01(\t\"9\n\x13\x44\x65scribeScoreOutput\x12\"\n\x05score\x18\x01 \x01(\x0b\x32\x13.eolymp.atlas.Score\"\x1d\n\x1b\x44\x65scribeProblemGradingInput\"\x8d\x01\n\x1c\x44\x65scribeProblemGradingOutput\x12@\n\x06ranges\x18\x02 \x03(\x0b\x32\x30.eolymp.atlas.DescribeProblemGradingOutput.Range\x1a+\n\x05Range\x12\r\n\x05grade\x18\x01 \x01(\r\x12\x13\n\x0bupper_bound\x18\x02 \x01(\x02\x32\xbf\x02\n\x0eScoringService\x12\x8e\x01\n\rDescribeScore\x12 .eolymp.atlas.DescribeScoreInput\x1a!.eolymp.atlas.DescribeScoreOutput\"8\x82\xe3\n\x19\x8a\xe3\n\x15\x61tlas:submission:read\x82\xd3\xe4\x93\x02\x15\x12\x13/scores/{member_id}\x12\x9b\x01\n\x16\x44\x65scribeProblemGrading\x12).eolymp.atlas.DescribeProblemGradingInput\x1a*.eolymp.atlas.DescribeProblemGradingOutput\"*\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\n\x12\x08/gradingB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.scoring_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_SCORINGSERVICE'].methods_by_name['DescribeScore']._loaded_options = None
  _globals['_SCORINGSERVICE'].methods_by_name['DescribeScore']._serialized_options = b'\202\343\n\031\212\343\n\025atlas:submission:read\202\323\344\223\002\025\022\023/scores/{member_id}'
  _globals['_SCORINGSERVICE'].methods_by_name['DescribeProblemGrading']._loaded_options = None
  _globals['_SCORINGSERVICE'].methods_by_name['DescribeProblemGrading']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\n\022\010/grading'
  _globals['_SCORECHANGEDEVENT']._serialized_start=150
  _globals['_SCORECHANGEDEVENT']._serialized_end=281
  _globals['_DESCRIBESCOREINPUT']._serialized_start=283
  _globals['_DESCRIBESCOREINPUT']._serialized_end=322
  _globals['_DESCRIBESCOREOUTPUT']._serialized_start=324
  _globals['_DESCRIBESCOREOUTPUT']._serialized_end=381
  _globals['_DESCRIBEPROBLEMGRADINGINPUT']._serialized_start=383
  _globals['_DESCRIBEPROBLEMGRADINGINPUT']._serialized_end=412
  _globals['_DESCRIBEPROBLEMGRADINGOUTPUT']._serialized_start=415
  _globals['_DESCRIBEPROBLEMGRADINGOUTPUT']._serialized_end=556
  _globals['_DESCRIBEPROBLEMGRADINGOUTPUT_RANGE']._serialized_start=513
  _globals['_DESCRIBEPROBLEMGRADINGOUTPUT_RANGE']._serialized_end=556
  _globals['_SCORINGSERVICE']._serialized_start=559
  _globals['_SCORINGSERVICE']._serialized_end=878
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/community/group_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/community/group_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.community import group_pb2 as eolymp_dot_community_dot_group__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/community/group_service.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1c\x65olymp/community/group.proto\x1a!eolymp/wellknown/expression.proto\"d\n\x11GroupChangedEvent\x12\'\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x17.eolymp.community.Group\x12&\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x17.eolymp.community.Group\":\n\x10\x43reateGroupInput\x12&\n\x05group\x18\x01 \x01(\x0b\x32\x17.eolymp.community.Group\"%\n\x11\x43reateGroupOutput\x12\x10\n\x08group_id\x18\x01 \x01(\t\"\xb2\x01\n\x10UpdateGroupInput\x12\x37\n\x05patch\x18\x01 \x03(\x0e\x32(.eolymp.community.UpdateGroupInput.Patch\x12\x10\n\x08group_id\x18\x02 \x01(\t\x12&\n\x05group\x18\x03 \x01(\x0b\x32\x17.eolymp.community.Group\"+\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\x0f\n\x0b\x44\x45SCRIPTION\x10\x02\"\x13\n\x11UpdateGroupOutput\"$\n\x10\x44\x65leteGroupInput\x12\x10\n\x08group_id\x18\x01 \x01(\t\"\x13\n\x11\x44\x65leteGroupOutput\"&\n\x12\x44\x65scribeGroupInput\x12\x10\n\x08group_id\x18\x01 \x01(\t\"=\n\x13\x44\x65scribeGroupOutput\x12&\n\x05group\x18\x01 \x01(\x0b\x32\x17.eolymp.community.Group\"\xe1\x01\n\x0fListGroupsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x39\n\x07\x66ilters\x18( \x01(\x0b\x32(.eolymp.community.ListGroupsInput.Filter\x1au\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"I\n\x10ListGroupsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.community.Group2\x9e\x06\n\x0cGroupService\x12\x93\x01\n\x0b\x43reateGroup\x12\".eolymp.community.CreateGroupInput\x1a#.eolymp.community.CreateGroupOutput\";\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:group:write\x82\xd3\xe4\x93\x02\t\"\x07/groups\x12\x9e\x01\n\x0bUpdateGroup\x12\".eolymp.community.UpdateGroupInput\x1a#.eolymp.community.UpdateGroupOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:group:write\x82\xd3\xe4\x93\x02\x14\"\x12/groups/{group_id}\x12\x9e\x01\n\x0b\x44\x65leteGroup\x12\".eolymp.community.DeleteGroupInput\x1a#.eolymp.community.DeleteGroupOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:group:write\x82\xd3\xe4\x93\x02\x14*\x12/groups/{group_id}\x12\xa3\x01\n\rDescribeGroup\x12$.eolymp.community.DescribeGroupInput\x1a%.eolymp.community.DescribeGroupOutput\"E\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14\x63ommunity:group:read\x82\xd3\xe4\x93\x02\x14\x12\x12/groups/{group_id}\x12\x8f\x01\n\nListGroups\x12!.eolymp.community.ListGroupsInput\x1a\".eolymp.community.ListGroupsOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14\x63ommunity:group:read\x82\xd3\xe4\x93\x02\t\x12\x07/groupsB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.group_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _globals['_GROUPSERVICE'].methods_by_name['CreateGroup']._loaded_options = None
  _globals['_GROUPSERVICE'].methods_by_name['CreateGroup']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025community:group:write\202\323\344\223\002\t\"\007/groups'
  _globals['_GROUPSERVICE'].methods_by_name['UpdateGroup']._loaded_options = None
  _globals['_GROUPSERVICE'].methods_by_name['UpdateGroup']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025community:group:write\202\323\344\223\002\024\"\022/groups/{group_id}'
  _globals['_GROUPSERVICE'].methods_by_name['DeleteGroup']._loaded_options = None
  _globals['_GROUPSERVICE'].methods_by_name['DeleteGroup']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025community:group:write\202\323\344\223\002\024*\022/groups/{group_id}'
  _globals['_GROUPSERVICE'].methods_by_name['DescribeGroup']._loaded_options = None
  _globals['_GROUPSERVICE'].methods_by_name['DescribeGroup']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024community:group:read\202\323\344\223\002\024\022\022/groups/{group_id}'
  _globals['_GROUPSERVICE'].methods_by_name['ListGroups']._loaded_options = None
  _globals['_GROUPSERVICE'].methods_by_name['ListGroups']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024community:group:read\202\323\344\223\002\t\022\007/groups'
  _globals['_GROUPCHANGEDEVENT']._serialized_start=222
  _globals['_GROUPCHANGEDEVENT']._serialized_end=322
  _globals['_CREATEGROUPINPUT']._serialized_start=324
  _globals['_CREATEGROUPINPUT']._serialized_end=382
  _globals['_CREATEGROUPOUTPUT']._serialized_start=384
  _globals['_CREATEGROUPOUTPUT']._serialized_end=421
  _globals['_UPDATEGROUPINPUT']._serialized_start=424
  _globals['_UPDATEGROUPINPUT']._serialized_end=602
  _globals['_UPDATEGROUPINPUT_PATCH']._serialized_start=559
  _globals['_UPDATEGROUPINPUT_PATCH']._serialized_end=602
  _globals['_UPDATEGROUPOUTPUT']._serialized_start=604
  _globals['_UPDATEGROUPOUTPUT']._serialized_end=623
  _globals['_DELETEGROUPINPUT']._serialized_start=625
  _globals['_DELETEGROUPINPUT']._serialized_end=661
  _globals['_DELETEGROUPOUTPUT']._serialized_start=663
  _globals['_DELETEGROUPOUTPUT']._serialized_end=682
  _globals['_DESCRIBEGROUPINPUT']._serialized_start=684
  _globals['_DESCRIBEGROUPINPUT']._serialized_end=722
  _globals['_DESCRIBEGROUPOUTPUT']._serialized_start=724
  _globals['_DESCRIBEGROUPOUTPUT']._serialized_end=785
  _globals['_LISTGROUPSINPUT']._serialized_start=788
  _globals['_LISTGROUPSINPUT']._serialized_end=1013
  _globals['_LISTGROUPSINPUT_FILTER']._serialized_start=896
  _globals['_LISTGROUPSINPUT_FILTER']._serialized_end=1013
  _globals['_LISTGROUPSOUTPUT']._serialized_start=1015
  _globals['_LISTGROUPSOUTPUT']._serialized_end=1088
  _globals['_GROUPSERVICE']._serialized_start=1091
  _globals['_GROUPSERVICE']._serialized_end=1889
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/discussion/thread_endpoint.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/discussion/thread_endpoint.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.discussion import thread_pb2 as eolymp_dot_discussion_dot_thread__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'eolymp/discussion/thread_endpoint.proto\x12\x11\x65olymp.discussion\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/discussion/thread.proto\"%\n\x13\x44\x65scribeThreadInput\x12\x0e\n\x06locale\x18\n \x01(\t\"A\n\x14\x44\x65scribeThreadOutput\x12)\n\x06thread\x18\x01 \x01(\x0b\x32\x19.eolymp.discussion.Thread\"3\n\x0fVoteThreadInput\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12\x0c\n\x04vote\x18\x02 \x01(\x05\"&\n\x10VoteThreadOutput\x12\x12\n\nvote_count\x18\x01 \x01(\x05\x32\x81\x02\n\x0eThreadEndpoint\x12z\n\x0e\x44\x65scribeThread\x12&.eolymp.discussion.DescribeThreadInput\x1a\'.eolymp.discussion.DescribeThreadOutput\"\x17\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x02\x12\x00\x12s\n\nVoteThread\x12\".eolymp.discussion.VoteThreadInput\x1a#.eolymp.discussion.VoteThreadOutput\"\x1c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x07\"\x05/voteB7Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.thread_endpoint_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _globals['_THREADENDPOINT'].methods_by_name['DescribeThread']._loaded_options = None
  _globals['_THREADENDPOINT'].methods_by_name['DescribeThread']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\002\022\000'
  _globals['_THREADENDPOINT'].methods_by_name['VoteThread']._loaded_options = None
  _globals['_THREADENDPOINT'].methods_by_name['VoteThread']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\007\"\005/vote'
  _globals['_DESCRIBETHREADINPUT']._serialized_start=161
  _globals['_DESCRIBETHREADINPUT']._serialized_end=198
  _globals['_DESCRIBETHREADOUTPUT']._serialized_start=200
  _globals['_DESCRIBETHREADOUTPUT']._serialized_end=265
  _globals['_VOTETHREADINPUT']._serialized_start=267
  _globals['_VOTETHREADINPUT']._serialized_end=318
  _globals['_VOTETHREADOUTPUT']._serialized_start=320
  _globals['_VOTETHREADOUTPUT']._serialized_end=358
  _globals['_THREADENDPOINT']._serialized_start=361
  _globals['_THREADENDPOINT']._serialized_end=618
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from eolymp.worker import worker_job_pb2 as _worker_job_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class JobTriggerEvent(_message.Message):
    __slots__ = ("job",)
    JOB_FIELD_NUMBER: _ClassVar[int]
    job: _worker_job_pb2.Job
    def __init__(self, job: _Optional[_Union[_worker_job_pb2.Job, _Mapping]] = ...) -> None: ...

class CreateJobInput(_message.Message):
    __slots__ = ("type", "inputs")
    class InputsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    TYPE_FIELD_NUMBER: _ClassVar[int]
    INPUTS_FIELD_NUMBER: _ClassVar[int]
    type: str
    inputs: _containers.ScalarMap[str, str]
    def __init__(self, type: _Optional[str] = ..., inputs: _Optional[_Mapping[str, str]] = ...) -> None: ...

class CreateJobOutput(_message.Message):
    __slots__ = ("job_id",)
    JOB_ID_FIELD_NUMBER: _ClassVar[int]
    job_id: str
    def __init__(self, job_id: _Optional[str] = ...) -> None: ...

class DescribeJobInput(_message.Message):
    __slots__ = ("job_id",)
    JOB_ID_FIELD_NUMBER: _ClassVar[int]
    job_id: str
    def __init__(self, job_id: _Optional[str] = ...) -> None: ...

class DescribeJobOutput(_message.Message):
    __slots__ = ("job",)
    JOB_FIELD_NUMBER: _ClassVar[int]
    job: _worker_job_pb2.Job
    def __init__(self, job: _Optional[_Union[_worker_job_pb2.Job, _Mapping]] = ...) -> None: ...

class ListJobsInput(_message.Message):
    __slots__ = ("offset", "size", "filters")
    class Filter(_message.Message):
        __slots__ = ("id", "type", "status")
        ID_FIELD_NUMBER: _ClassVar[int]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        type: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        status: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., type: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., status: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    filters: ListJobsInput.Filter
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListJobsInput.Filter, _Mapping]] = ...) -> None: ...

class ListJobsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_worker_job_pb2.Job]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_worker_job_pb2.Job, _Mapping]]] = ...) -> None: ...
